@@ -1,3 +1,5 @@
+/*	$NetBSD: regex.h,v 1.1.1.2 2008/05/18 14:31:38 aymeric Exp $ */
+
 /*-
  * Copyright (c) 1992 Henry Spencer.
  * Copyright (c) 1992, 1993
@@ -14,11 +16,7 @@
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *	This product includes software developed by the University of
- *	California, Berkeley and its contributors.
- * 4. Neither the name of the University nor the names of its contributors
+ * 3. Neither the name of the University nor the names of its contributors
  *    may be used to endorse or promote products derived from this software
  *    without specific prior written permission.
  *
@@ -42,7 +40,6 @@
 
 #ifdef __REGEX_PRIVATE
 #include "config.h"
-#include "port.h"
 #include "../common/multibyte.h"
 #endif
 
@@ -99,10 +96,20 @@ typedef struct {
 #define	REG_LARGE	01000	/* force large representation */
 #define	REG_BACKR	02000	/* force use of backref code */
 
-int	regcomp __P((regex_t *, const RCHAR_T *, int));
-size_t	regerror __P((int, const regex_t *, char *, size_t));
-int	regexec __P((const regex_t *,
-	    const RCHAR_T *, size_t, regmatch_t [], int));
-void	regfree __P((regex_t *));
+#ifdef USE_WIDECHAR
+/*
+ * Avoid function name conflicts with the system regex functions.
+ * This is needed e.g. to build with AddressSanitizer.
+ */
+#define regcomp nvi_regcomp
+#define regerror nvi_regerror
+#define regexec nvi_regexec
+#define regfree nvi_regfree
+#endif
+int	regcomp(regex_t *, const RCHAR_T *, int);
+size_t	regerror(int, const regex_t *, char *, size_t);
+int	regexec(const regex_t *,
+	    const RCHAR_T *, size_t, regmatch_t [], int);
+void	regfree(regex_t *);
 
 #endif /* !_REGEX_H_ */
